@@ -140,7 +140,7 @@ method described by Pekar and Staab (2002)
 
 =head1 CITATION
 
- inproceedings{Pekar:2002:TLF:1072228.1072318,
+ @inproceedings{Pekar:2002:TLF:1072228.1072318,
  author = {Pekar, Viktor and Staab, Steffen},
  title = {Taxonomy Learning: Factoring the Structure of a Taxonomy into a Semantic Classification Decision},
  booktitle = {Proceedings of the 19th International Conference on Computational Linguistics - Volume 1},
