@@ -108,11 +108,14 @@ sub getRelatedness
     #  calculate sanchez
     my $a = keys %intersection; 
     my $b = keys %union; 
-
-    if($b <= 0) { return -1.0000; }
-
-    my $score = -1 * (log( ($b-$a)/$b ) / log(2)); 
     
+    #   bounds check
+    if($b <= 0) { return -1.0000; }  
+    my $diff = $b-$a;
+    if($diff <= 0) { return -1.0000; }	
+
+    # get and return score
+    my $score = -1 * (log( ($diff)/$b ) / log(2)); 
     return $score;
 
 }
